import React from 'react';
import { Form, Table, Input, Button, Space } from 'antd';
import ProTable, { ProColumns, ProTableProps } from '@ant-design/pro-table';
import styles from './log.less';
import { useCallback } from 'react';
import { fetchApi } from '@/utils/request';
import { DATA } from '@/services/API';
import { throttle } from 'lodash';
import storage from '@/utils/storage';

enum LogActionType {
  Download = 'DOWNLOAD',
  Delete = 'DELETE',
  Upload = 'UPLOAD',
}

const tableColumns: Array<ProColumns<DATA.LogItem>> = [
  { dataIndex: 'archName', title: '名称', width: 150, ellipsis: true },
  {
    dataIndex: 'projName',
    title: '所属文件夹',
    search: false,
    width: 150,
    ellipsis: true,
  },
  // { dataIndex: 'size', title: '大小', search: false },
  {
    dataIndex: 'actionType',
    title: '操作类型',
    search: false,
    width: 96,
    valueEnum: {
      [LogActionType.Download]: '下载',
      [LogActionType.Delete]: '删除',
      [LogActionType.Upload]: '上传',
    },
    filters: true,
    onFilter: (v, record) => record.actionType === v,
  },
  { dataIndex: 'createUser', title: '操作人', search: false, width: 96 },
  {
    dataIndex: 'createTime',
    valueType: 'dateTime',
    width: 150,
    title: '操作时间',
    search: false,
    sorter: (a, b) => a.timestamp - b.timestamp,
    defaultSortOrder: 'descend',
  },
  // {
  //   search: false,
  //   render() {
  //     return (
  //       <div>
  //         查看
  //       </div>
  //     )
  //   }
  // },
];

export default function LogView() {
  const fetchLog = useCallback(
    throttle(async ({ archName }) => {
      const accountId = storage.get('accountId');
      const res = await fetchApi<DATA.LogItem[]>(
        'file/queryProjArchiveLogTbByCondition',
        { archName, createUserId: accountId },
      );
      if (res.data) {
        res.data.forEach((item) => {
          item.timestamp = new Date(item.createTime).getTime();
        });
      }
      return {
        success: res.requestIsSuccess,
        data: res.data || [],
      };
    }, 5000),
    [],
  );

  return (
    <div className={styles.logView}>
      <ProTable<DATA.LogItem>
        rowKey="id"
        search={{ span: { xs: 24, sm: 24, md: 12, lg: 12, xl: 8, xxl: 6 } }}
        className={styles.tableWrapper}
        tableClassName={styles.table}
        columns={tableColumns}
        toolBarRender={false}
        request={fetchLog}
        scroll={{ y: 'calc(100% - 47px)' }}
      />
    </div>
  );
}
